summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/slider.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/slider.h')
-rw-r--r--kalarm/lib/slider.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kalarm/lib/slider.h b/kalarm/lib/slider.h
index 8fa54d45..f79ac015 100644
--- a/kalarm/lib/slider.h
+++ b/kalarm/lib/slider.h
@@ -34,33 +34,34 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class Slider : public QSlider
+class Slider : public TQSlider
{
Q_OBJECT
- Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
+ TQ_OBJECT
+ TQ_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit Slider(TQWidget* parent = 0, const char* name = 0);
+ explicit Slider(TQWidget* tqparent = 0, const char* name = 0);
/** Constructor.
* @param orient The orientation of the slider, either Qt::Horizonal or Qt::Vertical.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit Slider(Orientation orient, TQWidget* parent = 0, const char* name = 0);
+ explicit Slider(Qt::Orientation orient, TQWidget* tqparent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the slider can have.
* @param maxValue The maximum value which the slider can have.
* @param pageStep The page step increment.
* @param value The initial value for the slider.
* @param orient The orientation of the slider, either Qt::Horizonal or Qt::Vertical.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- Slider(int minValue, int maxValue, int pageStep, int value, Orientation orient,
- TQWidget* parent = 0, const char* name = 0);
+ Slider(int minValue, int maxValue, int pageStep, int value, Qt::Orientation orient,
+ TQWidget* tqparent = 0, const char* name = 0);
/** Returns true if the slider is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the slider is read-only for the user.
@@ -34,33 +34,34 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -34,33 +34,34 @@
/** Constructor.
- * @param orient The orientation of the slider, either Qt::Horizonal or Qt::Vertical.
- * @param parent The parent object of this widget.
+ * @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -34,33 +34,34 @@
* @param pageStep The page step increment.
* @param value The initial value for the slider.
- * @param orient The orientation of the slider, either Qt::Horizonal or Qt::Vertical.
- * @param parent The parent object of this widget.
+ * @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/